@@ -1,3 +1,5 @@
+use crate::admin::AdminRequest;
+use crate::agreement_acceptances::{AgreementAcceptancesIdRequest, AgreementAcceptancesRequest};
 use crate::app_catalogs::AppCatalogsRequest;
 use crate::applications::{ApplicationsIdRequest, ApplicationsRequest};
 use crate::audit_logs::AuditLogsRequest;
@@ -43,6 +45,7 @@ use reqwest::Method;
 use std::convert::TryFrom;
 use std::fmt::Debug;
 use std::str::FromStr;
+use std::time::Duration;
 
 /// The graph client.
 ///
@@ -71,14 +74,20 @@ where
     /// Use the V1.0 api.
     pub fn v1(&'a self) -> Identify<'a, Client> {
         self.request.set_url(GraphUrl::from_str(GRAPH_URL).unwrap());
-        Identify { client: &self }
+        Identify { client: self }
     }
 
     /// Use the beta API.
     pub fn beta(&'a self) -> Identify<'a, Client> {
         self.request
             .set_url(GraphUrl::from_str(GRAPH_URL_BETA).unwrap());
-        Identify { client: &self }
+        Identify { client: self }
+    }
+
+    pub fn custom_endpoint(&'a self, custom_endpoint: &str) -> Identify<'a, Client> {
+        self.request
+            .set_url(GraphUrl::from_str(custom_endpoint).unwrap());
+        Identify { client: self }
     }
 
     /// Check if the current host is v1.0.
@@ -107,6 +116,11 @@ where
     pub(crate) fn request(&self) -> &Client {
         &self.request
     }
+
+    pub fn set_timeout(&self, duration: Duration) -> &Self {
+        self.request.set_timeout(duration);
+        self
+    }
 }
 
 impl<Client> Debug for Graph<Client>
@@ -281,11 +295,31 @@ impl<'a, Client> Identify<'a, Client>
 where
     Client: graph_http::RequestClient,
 {
+    pub fn admin(&self) -> AdminRequest<'a, Client> {
+        self.client.set_ident(ResourceIdentity::Admin);
+        AdminRequest::new(self.client)
+    }
+
     pub fn app_catalogs(&self) -> AppCatalogsRequest<'a, Client> {
         self.client.set_ident(ResourceIdentity::AppCatalogs);
         AppCatalogsRequest::new(self.client)
     }
 
+    pub fn agreement_acceptances(&self) -> AgreementAcceptancesRequest<'a, Client> {
+        self.client
+            .set_ident(ResourceIdentity::AgreementAcceptances);
+        AgreementAcceptancesRequest::new(self.client)
+    }
+
+    pub fn agreement_acceptance<S: AsRef<str>>(
+        &self,
+        id: S,
+    ) -> AgreementAcceptancesIdRequest<'a, Client> {
+        self.client
+            .set_ident(ResourceIdentity::AgreementAcceptances);
+        AgreementAcceptancesIdRequest::new(id.as_ref(), self.client)
+    }
+
     pub fn application<S: AsRef<str>>(&self, id: S) -> ApplicationsIdRequest<'a, Client> {
         self.client.set_ident(ResourceIdentity::Applications);
         ApplicationsIdRequest::new(id.as_ref(), self.client)
